Class: Puma::MiniSSL::Socket
- Inherits:
-
Object
- Object
- Puma::MiniSSL::Socket
- Defined in:
- lib/puma/minissl.rb
Instance Attribute Summary collapse
- #peeraddr ⇒ Object readonly
-
#peercert ⇒ OpenSSL::X509::Certificate?
readonly
OpenSSL is loaded in
MiniSSL::ContextBuilderwhenMiniSSL::Context#verify_modeis notVERIFY_NONE. -
#ssl_version_state ⇒ Object
readonly
Returns a two element array, first is protocol version (SSL_get_version), second is 'handshake' state (SSL_state_string).
- #to_io ⇒ Object readonly
Instance Method Summary collapse
- #close ⇒ Object
- #closed? ⇒ Boolean
- #engine_read_all ⇒ Object
- #flush ⇒ Object
-
#initialize(socket, engine) ⇒ Socket
constructor
A new instance of Socket.
- #read_nonblock(size, *_) ⇒ Object
- #readpartial(size) ⇒ Object
- #write(data) ⇒ Object (also: #syswrite, #<<)
-
#write_nonblock(data, *_) ⇒ Object
The problem with implementing it properly is that it means we'd have to have the ability to rewind an engine because after we write+extract, the socket write_nonblock call might raise an exception and later code would pass the same data in, but the engine would think it had already written the data in.
Constructor Details
#initialize(socket, engine) ⇒ Socket
Returns a new instance of Socket.
28 29 30 31 32 33 |
# File 'lib/puma/minissl.rb', line 28 def initialize(socket, engine) @socket = socket @engine = engine @peercert = nil @reuse = nil end |
Instance Attribute Details
#peeraddr ⇒ Object (readonly)
187 188 189 |
# File 'lib/puma/minissl.rb', line 187 def peeraddr @socket.peeraddr end |
#peercert ⇒ OpenSSL::X509::Certificate? (readonly)
OpenSSL is loaded in MiniSSL::ContextBuilder when
MiniSSL::Context#verify_mode is not VERIFY_NONE.
When VERIFY_NONE, MiniSSL::Engine#peercert is nil, regardless of
whether the client sends a cert.
197 198 199 200 201 202 203 204 |
# File 'lib/puma/minissl.rb', line 197 def peercert return @peercert if @peercert raw = @engine.peercert return nil unless raw @peercert = OpenSSL::X509::Certificate.new raw end |
#ssl_version_state ⇒ Object (readonly)
Returns a two element array, first is protocol version (SSL_get_version), second is 'handshake' state (SSL_state_string)
Used for dropping tcp connections to ssl. See OpenSSL ssl/ssl_stat.c SSL_state_string for info
53 54 55 |
# File 'lib/puma/minissl.rb', line 53 def ssl_version_state IS_JRUBY ? [nil, nil] : @engine.ssl_vers_st end |
#to_io ⇒ Object (readonly)
36 37 38 |
# File 'lib/puma/minissl.rb', line 36 def to_io @socket end |
Instance Method Details
#close ⇒ Object
172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/puma/minissl.rb', line 172 def close begin unless @engine.shutdown while alert_data = @engine.extract @socket.write alert_data end end rescue IOError, SystemCallError # nothing ensure @socket.close end end |
#closed? ⇒ Boolean
40 41 42 |
# File 'lib/puma/minissl.rb', line 40 def closed? @socket.closed? end |
#engine_read_all ⇒ Object
82 83 84 85 86 87 88 |
# File 'lib/puma/minissl.rb', line 82 def engine_read_all output = @engine.read while output and additional_output = @engine.read output << additional_output end output end |
#flush ⇒ Object
168 169 170 |
# File 'lib/puma/minissl.rb', line 168 def flush @socket.flush end |
#read_nonblock(size, *_) ⇒ Object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/puma/minissl.rb', line 90 def read_nonblock(size, *_) # *_ is to deal with keyword args that were added # at some point (and being used in the wild) while true output = engine_read_all return output if output data = @socket.read_nonblock(size, exception: false) if data == :wait_readable || data == :wait_writable # It would make more sense to let @socket.read_nonblock raise # EAGAIN if necessary but it seems like it'll misbehave on Windows. # I don't have a Windows machine to debug this so I can't explain # exactly whats happening in that OS. Please let me know if you # find out! # # In the meantime, we can emulate the correct behavior by # capturing :wait_readable & :wait_writable and raising EAGAIN # ourselves. raise IO::EAGAINWaitReadable elsif data.nil? raise SSLError.exception "HTTP connection?" if bad_tlsv1_3? return nil end @engine.inject(data) output = engine_read_all return output if output while neg_data = @engine.extract @socket.write neg_data end end end |
#readpartial(size) ⇒ Object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/puma/minissl.rb', line 65 def readpartial(size) while true output = @engine.read return output if output data = @socket.readpartial(size) @engine.inject(data) output = @engine.read return output if output while neg_data = @engine.extract @socket.write neg_data end end end |
#write(data) ⇒ Object Also known as: syswrite, <<
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/puma/minissl.rb', line 125 def write(data) return 0 if data.empty? data_size = data.bytesize need = data_size while true wrote = @engine.write data enc_wr = +'' while (enc = @engine.extract) enc_wr << enc end @socket.write enc_wr unless enc_wr.empty? need -= wrote return data_size if need == 0 data = data.byteslice(wrote..-1) end end |
#write_nonblock(data, *_) ⇒ Object
The problem with implementing it properly is that it means we'd have to have the ability to rewind an engine because after we write+extract, the socket write_nonblock call might raise an exception and later code would pass the same data in, but the engine would think it had already written the data in.
So for the time being (and since write blocking is quite rare), go ahead and actually block in write_nonblock.
164 165 166 |
# File 'lib/puma/minissl.rb', line 164 def write_nonblock(data, *_) write data end |